@@ -34,6 +34,7 @@ class TestUndercloudConfig(base.TestCase):
                     'custom_env_files',
                     'deployment_user',
                     'discovery_default_driver',
+                    'docker_bip',
                     'docker_insecure_registries',
                     'docker_registry_mirror',
                     'enable_node_discovery',
@@ -70,6 +71,7 @@ class TestUndercloudConfig(base.TestCase):
                     'undercloud_ntp_servers',
                     'undercloud_public_host',
                     'undercloud_service_certificate',
+                    'undercloud_timezone',
                     'undercloud_update_packages',
                     'upgrade_cleanup']
         self.assertEqual(expected, [x.name for x in ret])
@@ -85,6 +87,7 @@ class TestUndercloudConfig(base.TestCase):
                     'custom_env_files',
                     'deployment_user',
                     'discovery_default_driver',
+                    'docker_bip',
                     'docker_insecure_registries',
                     'docker_registry_mirror',
                     'enable_cinder',
@@ -131,18 +134,24 @@ class TestUndercloudConfig(base.TestCase):
                     'undercloud_ntp_servers',
                     'undercloud_public_host',
                     'undercloud_service_certificate',
+                    'undercloud_timezone',
                     'undercloud_update_packages',
                     'upgrade_cleanup']
         self.assertEqual(expected, [x.name for x in ret])
 
     def test_get_subnet_opts(self):
-        ret = self.config.get_subnet_opts()
         expected = ['cidr',
                     'dhcp_end',
+                    'dhcp_exclude',
                     'dhcp_start',
                     'gateway',
                     'inspection_iprange',
                     'masquerade']
+
+        ret = self.config.get_local_subnet_opts()
+        self.assertEqual(expected, [x.name for x in ret])
+
+        ret = self.config.get_remote_subnet_opts()
         self.assertEqual(expected, [x.name for x in ret])
 
     def test_get_undercloud_service_opts(self):
